==> ra-sdk-0.0.1-20191224.022434-2-sources.jar: com/xdja/ra/bean/EditIssueApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:47
 * @Description:
 */
public class EditIssueApplyInfo {
    /**
     * 非必须	申请原因
     */
    private String applyReason;
    /**
     * 非必须	证书主体DN
     */
    private String certDn;
    /**
     * 非必须	证书有效期
     */
    private Integer certValidity;
    /**
     * 非必须	密钥长度
     */
    private Integer privateKeyLength;
    /**
     * 非必须	证书签名算法
     */
    private String signAlg;
    /**
     * 非必须	模板名称
     */
    private String tempName;
    /**
     * 非必须	模板编号
     */
    private String tempNo;
    /**
     * 非必须	模板自定义参数
     */
    private String tempParas;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public Integer getPrivateKeyLength() {
        return privateKeyLength;
    }

    public void setPrivateKeyLength(Integer privateKeyLength) {
        this.privateKeyLength = privateKeyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public String getTempName() {
        return tempName;
    }

    public void setTempName(String tempName) {
        this.tempName = tempName;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public String getTempParas() {
        return tempParas;
    }

    public void setTempParas(String tempParas) {
        this.tempParas = tempParas;
    }

    @Override
    public String toString() {
        return "EditIssueApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", privateKeyLength=" + privateKeyLength +
                ", signAlg='" + signAlg + '\'' +
                ", tempName='" + tempName + '\'' +
                ", tempNo='" + tempNo + '\'' +
                ", tempParas='" + tempParas + '\'' +
                '}';
    }
}

==> ra-sdk-2.0.0-20210115.083039-19-sources.jar: com/xdja/ra/bean/EditIssueApplyInfo.java <==
package com.xdja.ra.bean;

import java.util.List;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:47
 * @Description:
 */
public class EditIssueApplyInfo {
    /**
     * 非必须	申请原因
     */
    private String applyReason;
    /**
     * 非必须	证书主体DN
     */
    private String certDn;
    /**
     * 非必须	证书有效期
     */
    private Integer certValidity;

    /**
     * 非必须	模板编号
     */
    private String tempNo;
    /**
     * 非必须	模板自定义参数
     */
    private List<Extension> extensionList;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public List<Extension> getExtensionList() {
        return extensionList;
    }

    public void setExtensionList(List<Extension> extensionList) {
        this.extensionList = extensionList;
    }

    @Override
    public String toString() {
        return "EditIssueApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", tempNo='" + tempNo + '\'' +
                ", extensionList=" + extensionList +
                '}';
    }
}
